==> csv-5.3.0.jar: META-INF/resources/webjars/csv/5.3.0/CHANGELOG.md <==

# Changelog

See the changelogs of our child projects:

* [csv-generate](https://github.com/adaltas/node-csv-generate/blob/master/CHANGELOG.md)
* [csv-parse](https://github.com/adaltas/node-csv-parse/blob/master/CHANGELOG.md)
* [csv-stringify](https://github.com/adaltas/node-csv-stringify/blob/master/CHANGELOG.md)
* [stream-transform](https://github.com/adaltas/node-stream-transform/blob/master/CHANGELOG.md)

## Version 5.3.0

* csv-parse: version 4.8.0

## Version 5.2.0

* csv-parse: version 4.7.0
* package: contributing
* package: code of conduct

## Version 5.1.3

* travis: add node.js 12
* csv-parse: version 4.4.6

## Version 5.1.2

* csv-generate: version 3.2.3
* csv-parse: version 4.4.5
* csv-stringify: version 5.3.3
* stream-transform: version 2.0.1
* ts: new definition files
* project: fix license in package.json

## Version 5.1.1

* es5: fix modules to wrap es5 dependencies

## Version 5.1.0

* csv-generate: version 3.2.0
* csv-stringify: version 5.1.2
* csv-parse: version 4.3.0
* stream-transform: version 1.0.8
* babel: re-integration

## Version 5.0.1

* all: modules written in native JavaScript
* package: switch to MIT license

## Version 5.0.0

* csv-generate: version 3.1.0
* csv-stringify: version 5.0.0
* csv-parse: version 4.0.1
* travis: test with Node.js 8, 10 and 11

## Version 4.0.0

* es5: support older version of Node.js using Babel
* readme: update project website url
* sync: expose the sync api
* samples: new pipe_funny script
* samples: rewrite pipe with comments

## Version 3.1.0

* csv-parse  ^2.2.0  →  ^2.4.0
* package: ignore lock files

## Version 3.0.2

* package: generate js file before release

## Version 3.0.1

* package: attempt to re-submit NPM package, no ./lib/index.js present

## Version 3.0.0

* csv-generate: "^2.0.2"
* csv-parse: "^2.2.0"
* stream-transform: "^1.0.2"
* csv-stringify: "^3.0.0"

==> csv-5.5.0.jar: META-INF/resources/webjars/csv/5.5.0/CHANGELOG.md <==

# Changelog

See the changelogs of our child projects:

* [csv-generate](https://github.com/adaltas/node-csv-generate/blob/master/CHANGELOG.md)
* [csv-parse](https://github.com/adaltas/node-csv-parse/blob/master/CHANGELOG.md)
* [csv-stringify](https://github.com/adaltas/node-csv-stringify/blob/master/CHANGELOG.md)
* [stream-transform](https://github.com/adaltas/node-stream-transform/blob/master/CHANGELOG.md)

## Version 5.5.0

feat: browersify

## Version 5.4.0

* csv-generate: 3.3.0
* csv-parse: 4.15.3
* stream-transform: 2.0.4
* csv-stringify: 5.6.2

## Version 5.3.2

* package: update project description
* csv-parse: 4.8.8
* csv-stringify: 5.3.6

## Version 5.3.1

* csv-generate: 3.2.4 
* csv-parse: 4.8.2 
* csv-stringify: 5.3.4

## Version 5.3.0

* csv-parse: version 4.8.0

## Version 5.2.0

* csv-parse: version 4.7.0
* package: contributing
* package: code of conduct

## Version 5.1.3

* travis: add node.js 12
* csv-parse: version 4.4.6

## Version 5.1.2

* csv-generate: version 3.2.3
* csv-parse: version 4.4.5
* csv-stringify: version 5.3.3
* stream-transform: version 2.0.1
* ts: new definition files
* project: fix license in package.json

## Version 5.1.1

* es5: fix modules to wrap es5 dependencies

## Version 5.1.0

* csv-generate: version 3.2.0
* csv-stringify: version 5.1.2
* csv-parse: version 4.3.0
* stream-transform: version 1.0.8
* babel: re-integration

## Version 5.0.1

* all: modules written in native JavaScript
* package: switch to MIT license

## Version 5.0.0

* csv-generate: version 3.1.0
* csv-stringify: version 5.0.0
* csv-parse: version 4.0.1
* travis: test with Node.js 8, 10 and 11

## Version 4.0.0

* es5: support older version of Node.js using Babel
* readme: update project website url
* sync: expose the sync api
* samples: new pipe_funny script
* samples: rewrite pipe with comments

## Version 3.1.0

* csv-parse  ^2.2.0  →  ^2.4.0
* package: ignore lock files

## Version 3.0.2

* package: generate js file before release

## Version 3.0.1

* package: attempt to re-submit NPM package, no ./lib/index.js present

## Version 3.0.0

* csv-generate: "^2.0.2"
* csv-parse: "^2.2.0"
* stream-transform: "^1.0.2"
* csv-stringify: "^3.0.0"
